@@ -1,23 +1,14 @@
-from Acquisition import aq_parent
-from zope.component.hooks import getSite
-from zope.component import getUtility
+# -*- coding: utf-8 -*-
+from archetypes.multilingual.interfaces import IArchetypesTranslatable
+from Products.CMFPlone.interfaces import ILanguage
+from plone.app.multilingual.interfaces import ILanguageIndependentFieldsManager
+from plone.app.multilingual.interfaces import ITranslationManager
 from zope.component import queryAdapter
 from zope.event import notify
 from zope.lifecycleevent import Attributes
 from zope.lifecycleevent import ObjectModifiedEvent
 from zope.lifecycleevent.interfaces import IObjectModifiedEvent
 
-from Products.CMFCore.utils import getToolByName
-
-from archetypes.multilingual.interfaces import IArchetypesTranslatable
-
-from plone.multilingual.interfaces import ILanguage
-from plone.multilingual.interfaces import ITranslatable
-from plone.multilingual.interfaces import ILanguageIndependentFieldsManager
-from plone.multilingual.interfaces import ITranslationManager
-
-from Products.CMFPlone.interfaces import IPloneSiteRoot
-
 
 class LanguageIndependentModifier(object):
     """Class to handle archetypes editions."""
@@ -66,5 +57,9 @@ class LanguageIndependentModifier(object):
                 translations_list_to_process.append(translations[language])
         return translations_list_to_process
 
-handler = LanguageIndependentModifier()
+    @property
+    def __name__(self):
+        return "handler"
 
+
+handler = LanguageIndependentModifier()
